Module: RFacter::DSL::Facter::Core

Defined in:
lib/rfacter/dsl.rb

Overview

Facter::Core DSL methods

Since:

  • 0.1.0

Defined Under Namespace

Modules: Execution

Constant Summary collapse

Aggregate =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Aggregates provide a mechanism for facts to be resolved in multiple steps.

Aggregates are evaluated in two parts: generating individual chunks and then aggregating all chunks together. Each chunk is a block of code that generates a value, and may depend on other chunks when it runs. After all chunks have been evaluated they are passed to the aggregate block as ‘Hash<name, result>`. The aggregate block converts the individual chunks into a single value that is returned as the final value of the aggregate.

Since:

  • 0.1.0

::RFacter::Core::Aggregate